This is the mail archive of the binutils@sourceware.org mailing list for the binutils project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[PATCH bfin] Add .l2.text and .l2.data sections support to FD-PIC ld


This patch just adds .l2.text and .l2.data sections support to Blackfin ld for ELF FD-PIC ABI. They are used by applications of that ABI to utilize the fast L2 SRAM of some Blackfin processors.

Committed.


Jie
	* emulparams/elf32bfinfd.sh (OTHER_SECTIONS): Add .l2.text
	and .l2.data.

Index: emulparams/elf32bfinfd.sh
===================================================================
RCS file: /cvs/src/src/ld/emulparams/elf32bfinfd.sh,v
retrieving revision 1.5
diff -u -r1.5 elf32bfinfd.sh
--- emulparams/elf32bfinfd.sh	15 Jul 2008 13:09:47 -0000	1.5
+++ emulparams/elf32bfinfd.sh	4 Sep 2009 04:06:37 -0000
@@ -14,9 +14,18 @@
     ${RELOCATING+__ROFIXUP_END__ = .;}
   }
 "
 # 0xff700000, 0xff800000, 0xff900000 and 0xffa00000 are also used in
 # Dynamic linker and linux kernel. They need to be keep synchronized.
 OTHER_SECTIONS="
+  .l2.text 0xfeb00000	:
+  {
+    *(.l2.text)
+  }
+  .l2.data 0xfec00000	:
+  {
+    *(.l2.data)
+  }
   .l1.data 0xff700000	:
   {
     *(.l1.data)
@@ -14,9 +14,18 @@
   }
 "
-# 0xff700000, 0xff800000, 0xff900000 and 0xffa00000 are also used in
-# Dynamic linker and linux kernel. They need to be keep synchronized.
+# 0xfeb00000, 0xfec00000, 0xff700000, 0xff800000, 0xff900000
+# 0xffa00000 are also used in Dynamic linker and linux kernel.
+# They need to be kept synchronized.
 OTHER_SECTIONS="

Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]